import { Breadcrumbs } from "@/components/global/Breadcrumbs";
import { generateBreadcrumbsFromPath } from "@/utils/generateBreadcrumbs";
import { notFound } from "next/navigation";
import { ReactNode } from "react";

export default async function SubLayout({
  children
}: {
  children: ReactNode
}) {
  const segments = getSegmentsFromUrl();

  const breadcrumbs = await generateBreadcrumbsFromPath(segments);
  if (!breadcrumbs) return notFound();

  return (
    <div className="px-4 py-6">
      <Breadcrumbs items={breadcrumbs} />
      {children}
    </div>
  );
}

function getSegmentsFromUrl(): string[] {
  const path = decodeURIComponent(
    // remove leading slash
    (typeof window !== "undefined" ? window.location.pathname : "")
      .replace(/^\//, "")
  );
  return path.split("/").filter(Boolean);
}